"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class GraphqlAuthenticationPrismaAdapter {
    constructor(options) {
        this.prismaContextName = 'db';
        if (options.prismaContextName) {
            this.prismaContextName = options.prismaContextName;
        }
    }
    db(ctx) {
        const db = ctx[this.prismaContextName];
        if (!db) {
            throw new Error(`The Prisma binding is not attached to the \`${this.prismaContextName}\` property on your context.`);
        }
        return db;
    }
    findUserById(ctx, id, info) {
        return this.db(ctx).query.user({ where: { id } }, info);
    }
    findUserByEmail(ctx, email, info) {
        return this.db(ctx).query.user({
            where: { email: email }
        }, info);
    }
    userExistsByEmail(ctx, email) {
        return this.db(ctx).exists.User({ email });
    }
    createUser(ctx, data) {
        return this.db(ctx).mutation.createUser({
            data
        });
    }
    createUserBySignup(ctx, data) {
        return this.createUser(ctx, data);
    }
    createUserByInvite(ctx, data) {
        return this.createUser(ctx, data);
    }
    updateUser(ctx, userId, data) {
        return this.db(ctx).mutation.updateUser({
            where: { id: userId },
            data
        });
    }
    updateUserConfirmToken(ctx, userId, data) {
        return this.updateUser(ctx, userId, data);
    }
    updateUserLastLogin(ctx, userId, data) {
        return this.updateUser(ctx, userId, data);
    }
    updateUserPassword(ctx, userId, data) {
        return this.updateUser(ctx, userId, data);
    }
    updateUserResetToken(ctx, userId, data) {
        return this.updateUser(ctx, userId, data);
    }
    updateUserInfo(ctx, userId, data) {
        return this.updateUser(ctx, userId, data);
    }
    updateUserCompleteInvite(ctx, userId, data) {
        return this.updateUser(ctx, userId, data);
    }
}
exports.GraphqlAuthenticationPrismaAdapter = GraphqlAuthenticationPrismaAdapter;
